package VMOMI::ClusterPowerOnVmOption;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
